@@ -1,5 +1,5 @@
 # -*- test-case-name: twisted.conch.test.test_keys -*-
-# Copyright (c) 2001-2010 Twisted Matrix Laboratories.
+# Copyright (c) Twisted Matrix Laboratories.
 # See LICENSE for details.
 
 """
@@ -461,9 +461,9 @@ class Key(object):
         'RSA' or 'DSA'.
         """
         # the class is Crypto.PublicKey.<type>.<stuff we don't care about>
-        klass = str(self.keyObject.__class__)
-        if klass.startswith('Crypto.PublicKey'):
-            type = klass.split('.')[2]
+        mod = self.keyObject.__class__.__module__
+        if mod.startswith('Crypto.PublicKey'):
+            type = mod.split('.')[2]
         else:
             raise RuntimeError('unknown type of object: %r' % self.keyObject)
         if type in ('RSA', 'DSA'):
@@ -729,121 +729,6 @@ class Key(object):
             digest = sha1(data).digest()
         return self.keyObject.verify(digest, numbers)
 
-def getPublicKeyString(filename=None, line=0, data=''):
-    """
-    Return a public key string suitable for being sent over the wire.
-    Takes a filename or data of a public key.  Currently handles OpenSSH
-    and LSH keys.
-
-    This function has been deprecated since Twisted Conch 0.9.  Use
-    Key.fromString() instead.
-
-    @type filename: C{str}
-    @type line:     C{int}
-    @type data:     C{str}
-    @rtype:         C{str}
-    """
-    warnings.warn("getPublicKeyString is deprecated since Twisted Conch 0.9."
-            "  Use Key.fromString().blob().",
-            DeprecationWarning, stacklevel=2)
-    if filename and data:
-        raise BadKeyError("either filename or data, not both")
-    if filename:
-        lines = open(filename).readlines()
-        data = lines[line]
-    return Key.fromString(data).blob()
-
-def makePublicKeyString(obj, comment='', kind='openssh'):
-    """
-    Return an public key given a C{Crypto.PublicKey.pubkey.pubkey}
-    object.
-    kind is one of ('openssh', 'lsh')
-
-    This function is deprecated since Twisted Conch 0.9.  Instead use
-    Key(obj).toString().
-
-    @type obj:      C{Crypto.PublicKey.pubkey.pubkey}
-    @type comment:  C{str}
-    @type kind:     C{str}
-    @rtype:         C{str}
-    """
-    warnings.warn("makePublicKeyString is deprecated since Twisted Conch 0.9."
-            "  Use Key(obj).public().toString().",
-            DeprecationWarning, stacklevel=2)
-    return Key(obj).public().toString(kind, comment)
-
-def getPublicKeyObject(data):
-    """
-    Return a C{Crypto.PublicKey.pubkey.pubkey} corresponding to the SSHv2
-    public key data.  data is in the over-the-wire public key format.
-
-    This function is deprecated since Twisted Conch 0.9. Instead, use
-    Key.fromString().
-
-    @type data:     C{str}
-    @rtype:         C{Crypto.PublicKey.pubkey.pubkey}
-    """
-    warnings.warn("getPublicKeyObject is deprecated since Twisted Conch 0.9."
-            "  Use Key.fromString().",
-            DeprecationWarning, stacklevel=2)
-    return Key.fromString(data).keyObject
-
-def getPrivateKeyObject(filename=None, data='', passphrase=''):
-    """
-    Return a C{Crypto.PublicKey.pubkey.pubkey} object corresponding to the
-    private key file/data.  If the private key is encrypted, passphrase B{must}
-    be specified, other wise a L{BadKeyError} will be raised.
-
-    This method is deprecated since Twisted Conch 0.9.  Instead, use
-    the fromString or fromFile classmethods of Key.
-
-    @type filename:     C{str}
-    @type data:         C{str}
-    @type passphrase:   C{str}
-    @rtype: C{Crypto.PublicKey.pubkey.pubkey}
-    @raises BadKeyError: if the key is invalid or a passphrase is not specified
-    """
-    warnings.warn("getPrivateKeyObject is deprecated since Twisted Conch 0.9."
-            "  Use Key.fromString().",
-            DeprecationWarning, stacklevel=2)
-    if filename and data:
-        raise BadKeyError("either filename or data, not both")
-    if filename:
-        return Key.fromFile(filename, passphrase=passphrase).keyObject
-    else:
-        return Key.fromString(data, passphrase=passphrase).keyObject
-
-def makePrivateKeyString(obj, passphrase=None, kind='openssh'):
-    """
-    Return an OpenSSH-style private key for a
-    C{Crypto.PublicKey.pubkey.pubkey} object.  If passphrase is given, encrypt
-    the private key with it.
-    kind is one of ('openssh', 'lsh', 'agentv3')
-
-    This function is deprecated since Twisted Conch 0.9. Instead use
-    Key(obj).toString().
-
-    @type obj:          C{Crypto.PublicKey.pubkey.pubkey}
-    @type passphrase:   C{str}/C{None}
-    @type kind:         C{str}
-    @rtype:             C{str}
-    """
-    warnings.warn("makePrivateKeyString is deprecated since Twisted Conch 0.9."
-            "  Use Key(obj).toString().",
-            DeprecationWarning, stacklevel=2)
-    return Key(obj).toString(kind, passphrase)
-
-def makePublicKeyBlob(obj):
-    """
-    Make a public key blob from a C{Crypto.PublicKey.pubkey.pubkey}.
-
-    This function is deprecated since Twisted Conch 0.9.  Use
-    Key().blob() instead.
-    """
-    warnings.warn("makePublicKeyBlob is deprecated since Twisted Conch 0.9."
-            "  Use Key(obj).blob().",
-            DeprecationWarning, stacklevel=2)
-    return Key(obj).blob()
 
 def objectType(obj):
     """
@@ -891,51 +776,5 @@ def lenSig(obj):
     """
     return obj.size()/8
 
-def signData(obj, data):
-    """
-    Sign the data with the given C{Crypto.PublicKey.pubkey.pubkey} object.
-
-    This method is deprecated since Twisted Conch 0.9.  Instead use
-    Key().sign().
-
-    @type obj:  C{Crypto.PublicKey.pubkey.pubkey}
-    @type data: C{str}
-    @rtype:     C{str}
-    """
-    warnings.warn("signData is deprecated since Twisted Conch 0.9."
-            "  Use Key(obj).sign(data).",
-            DeprecationWarning, stacklevel=2)
-    return Key(obj).sign(data)
-
-def verifySignature(obj, sig, data):
-    """
-    Verify that the signature for the data is valid.
-
-    This method is deprecated since Twisted Conch 0.9.  Use
-    Key().verify().
-
-    @type obj:  C{Crypto.PublicKey.pubkey.pubkey}
-    @type sig:  C{str}
-    @type data: C{str}
-    @rtype:     C{bool}
-    """
-    warnings.warn("verifySignature is deprecated since Twisted Conch 0.9."
-            "  Use Key(obj).verify(signature, data).",
-            DeprecationWarning, stacklevel=2)
-    return Key(obj).verify(sig, data)
-
-def printKey(obj):
-    """
-    Pretty print a C{Crypto.PublicKey.pubkey.pubkey} object.
-
-    This function is deprecated since Twisted Conch 0.9.  Use
-    repr(Key()).
-
-    @type obj: C{Crypto.PublicKey.pubkey.pubkey}
-    """
-    warnings.warn("printKey is deprecated since Twisted Conch 0.9."
-            "  Use repr(Key(obj)).",
-            DeprecationWarning, stacklevel=2)
-    return repr(Key(obj))[1:-1]
 
 ID_SHA1 = '\x30\x21\x30\x09\x06\x05\x2b\x0e\x03\x02\x1a\x05\x00\x04\x14'
