@@ -1,5 +1,5 @@
 # -*- test-case-name: twisted.conch.test.test_tap -*-
-# Copyright (c) 2001-2009 Twisted Matrix Laboratories.
+# Copyright (c) Twisted Matrix Laboratories.
 # See LICENSE for details.
 
 """
@@ -23,12 +23,16 @@ class Options(usage.Options):
     longdesc = "Makes a Conch SSH server."
     optParameters = [
          ["interface", "i", "", "local interface to which we listen"],
-         ["port", "p", "22", "Port on which to listen"],
+         ["port", "p", "tcp:22", "Port on which to listen"],
          ["data", "d", "/etc", "directory to look for host keys in"],
          ["moduli", "", None, "directory to look for moduli in "
                               "(if different from --data)"]
     ]
-    zsh_actions = {"data" : "_dirs", "moduli" : "_dirs"}
+    compData = usage.Completions(
+        optActions={"data" : usage.CompleteDirs(descr="data directory"),
+                    "moduli" : usage.CompleteDirs(descr="moduli directory"),
+                    "interface" : usage.CompleteNetInterfaces()}
+        )
 
 
 def makeService(config):
